"""Customized extensions for EPP commands."""

from dataclasses import dataclass
from typing import Any, Optional

from epplib.commands.command_extensions import UpdateContactMailingAddressExtension


@dataclass
class UpdateContactMailingAddressExtensionGuard(UpdateContactMailingAddressExtension):
    """Mailing address extension for the EPPIC update-contact command.

    Guards from unintentionally unsetting mailing address using deprecated combination of arguments.
    """

    def __new__(cls, **kwargs: Any) -> Optional["UpdateContactMailingAddressExtensionGuard"]:  # type: ignore[misc]
        """Return a new instance or `None` if no meaningful arguments are given."""
        if not kwargs.get("rem") and not kwargs.get("addr"):
            # Passing `addr = None` to the super class would clear the mailing address.
            # This is only desired if `rem = True`. With falsy `rem`, behave like if not specified at all.
            return None
        return super().__new__(cls)
