from unittest import TestCase

from epplib.models import ExtraAddr

from eppic.commands.epp_extensions import UpdateContactMailingAddressExtensionGuard


class UpdateContactMailingAddressExtensionGuardTest(TestCase):
    ADDR = ExtraAddr(street=["asdf"], city="Praha", cc="CZ", pc="12345")

    def test_addr(self):
        mailing = UpdateContactMailingAddressExtensionGuard(addr=self.ADDR)
        self.assertEqual(mailing.addr, self.ADDR)
        self.assertFalse(mailing.rem)

    def test_addr_rem_false(self):
        mailing = UpdateContactMailingAddressExtensionGuard(addr=self.ADDR, rem=False)
        self.assertEqual(mailing.addr, self.ADDR)
        self.assertFalse(mailing.rem)

    def test_addr_rem_true(self):
        mailing = UpdateContactMailingAddressExtensionGuard(addr=self.ADDR, rem=True)
        with self.assertRaisesRegex(ValueError, "Cannot set and remove the mailing address at the same time."):
            mailing.get_payload()

    def test_rem_false(self):
        mailing = UpdateContactMailingAddressExtensionGuard(rem=False)
        self.assertIsNone(mailing)

    def test_rem_true(self):
        mailing = UpdateContactMailingAddressExtensionGuard(rem=True)
        self.assertIsNone(mailing.addr)
